@@ -1,11 +1,3 @@
-"""
-BMI calculation
-^^^^^^^^^^^^^^^
-
-Simple application for calculating `Body Mass Index <https://en.wikipedia.org/wiki/Body_mass_index>`_
-
-:demo_host:`Demo </bmi>`, `Source code <https://github.com/wang0618/PyWebIO/blob/dev/demos/bmi.py>`_
-"""
 from pywebio import start_server
 from pywebio.input import *
 from pywebio.output import *
@@ -59,7 +51,7 @@ def main():
     ## BMI指数计算器
     本程序的源代码[链接](https://github.com/wang0618/PyWebIO/blob/dev/demos/bmi.py)
     
-    """), strip_indent=4)
+    """))
 
     info = input_group(t('BMI calculation', '计算BMI：'), [
         input(t("Your Height(cm)", "请输入你的身高(cm)"), name="height", type=FLOAT),
@@ -79,4 +71,4 @@ def main():
 
 
 if __name__ == '__main__':
-    start_server(main, debug=True, port=8080, cdn=False)
+    start_server(main, debug=True, port=8080)
