@@ -91,13 +91,14 @@ PASSWORD = "password"
 URL = "url"
 DATE = "date"
 TIME = "time"
+COLOR = "color"
 
 CHECKBOX = 'checkbox'
 RADIO = 'radio'
 SELECT = 'select'
 TEXTAREA = 'textarea'
 
-__all__ = ['TEXT', 'NUMBER', 'FLOAT', 'PASSWORD', 'URL', 'DATE', 'TIME', 'input', 'textarea', 'select',
+__all__ = ['TEXT', 'NUMBER', 'FLOAT', 'PASSWORD', 'URL', 'DATE', 'TIME', 'COLOR', 'input', 'textarea', 'select',
            'checkbox', 'radio', 'actions', 'file_upload', 'slider', 'input_group', 'input_update']
 
 
@@ -133,7 +134,7 @@ def input(label='', type=TEXT, *, validate=None, name=None, value=None, action=N
     r"""Text input
 
     :param str label: Label of input field.
-    :param str type: Input type. Currently supported types are：`TEXT` , `NUMBER` , `FLOAT` , `PASSWORD` , `URL` , `DATE` , `TIME`
+    :param str type: Input type. Currently, supported types are：`TEXT` , `NUMBER` , `FLOAT` , `PASSWORD` , `URL` , `DATE` , `TIME`, `COLOR`
 
        Note that `DATE` and `TIME` type are not supported on some browsers,
        for details see https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#Browser_compatibility
@@ -204,7 +205,7 @@ def input(label='', type=TEXT, *, validate=None, name=None, value=None, action=N
         Note: When using :ref:`Coroutine-based session <coroutine_based_session>` implementation, the ``callback``
         function can be a coroutine function.
 
-    :param callable onchange: A callback function which will be called when the value of this input field changed.
+    :param callable onchange: A callback function which will be called when user change the value of this input field.
 
        The ``onchange`` callback is invoked with one argument, the current value of input field.
        A typical usage scenario of ``onchange`` is to update other input item by using `input_update()`
@@ -222,7 +223,7 @@ def input(label='', type=TEXT, *, validate=None, name=None, value=None, action=N
     item_spec, valid_func, onchange_func = _parse_args(locals(), excludes=('action',))
 
     # check input type
-    allowed_type = {TEXT, NUMBER, FLOAT, PASSWORD, URL, DATE, TIME}
+    allowed_type = {TEXT, NUMBER, FLOAT, PASSWORD, URL, DATE, TIME, COLOR}
     assert type in allowed_type, 'Input type not allowed.'
 
     value_setter = None
@@ -448,7 +449,7 @@ def _parse_action_buttons(buttons):
 
         act.setdefault('type', 'submit')
         assert act['type'] in ('submit', 'reset', 'cancel'), \
-            "submit type muse be 'submit'/'reset'/'cancel', not %r" % act['type']
+            "submit type must be 'submit'/'reset'/'cancel', not %r" % act['type']
         act_res.append(act)
 
     return act_res
