@@ -78,6 +78,7 @@ Here lists the difference between the two in parameters:
  * The first parameter of pin widget function is always the name of the widget,
    and if you output two pin widgets with the same name, the previous one will expire.
  * Pin functions don't support the ``on_change`` and ``validate`` callbacks, and the ``required`` parameter.
+   (There is a :func:`pin_on_change()` function as an alternative to ``on_change``)
  * Pin functions have additional ``scope`` and ``position`` parameters for output control.
 
 .. autofunction:: put_input
@@ -95,7 +96,8 @@ Pin utils
     Pin widgets value getter and setter.
 
     You can use attribute or key index of ``pin`` object to get the current value of a pin widget.
-    When accessing the value of a widget that does not exist, it returns ``None`` instead of throwing an exception.
+    By default, when accessing the value of a widget that does not exist, it returns ``None`` instead of
+    throwing an exception.
 
     You can also use the ``pin`` object to set the value of pin widget:
 
@@ -113,9 +115,12 @@ Pin utils
     Note: When using :ref:`coroutine-based session <coroutine_based_session>`,
     you need to use the ``await pin.name`` (or ``await pin['name']``) syntax to get pin widget value.
 
+    Use `pin.pin.use_strict()` to enable strict mode for getting pin widget value.
+    An ``AssertionError`` will be raised when try to get value of pin widgets that are currently not in the page.
 
 .. autofunction:: pin_wait_change
 .. autofunction:: pin_update
+.. autofunction:: pin_on_change
 
 """
 
@@ -124,18 +129,18 @@ import string
 from pywebio.input import parse_input_update_spec
 from pywebio.output import OutputPosition, Output
 from pywebio.output import _get_output_spec
-from .io_ctrl import send_msg, single_input_kwargs
+from .io_ctrl import send_msg, single_input_kwargs, output_register_callback
 from .session import next_client_event, chose_impl
 
-_html_value_chars = set(string.ascii_letters + string.digits + '_')
+_pin_name_chars = set(string.ascii_letters + string.digits + '_-')
 
 __all__ = ['put_input', 'put_textarea', 'put_select', 'put_checkbox', 'put_radio', 'put_slider', 'put_actions',
-           'pin', 'pin_update', 'pin_wait_change']
+           'pin', 'pin_update', 'pin_wait_change', 'pin_on_change']
 
 
 def check_name(name):
-    assert all(i in _html_value_chars for i in name), "pin `name` can only contain letters, digits and underscore"
-    assert name[0] in string.ascii_letters, "pin `name` can only starts with letters"
+    assert all(i in _pin_name_chars for i in name), "pin `name` can only contain letters, digits, " \
+                                                    "minus sign and underscore"
 
 
 def _pin_output(single_input_return, scope, position):
@@ -231,26 +236,44 @@ def get_client_val():
     return res['data']
 
 
+@chose_impl
+def get_pin_value(name, strict):
+    send_msg('pin_value', spec=dict(name=name))
+    data = yield get_client_val()
+    assert not strict or data, 'pin widget "%s" doesn\'t exist.' % name
+    return (data or {}).get('value')
+
+
 class Pin_:
+    _strict = False
+
+    def use_strict(self):
+        """
+        Enable strict mode for getting pin widget value.
+        An AssertionError will be raised when try to get value of pin widgets that are currently not in the page.
+        """
+        object.__setattr__(self, '_strict', True)
 
     def __getattr__(self, name):
         """__getattr__ is only invoked if the attribute wasn't found the usual ways"""
-        check_name(name)
-        send_msg('pin_value', spec=dict(name=name))
-        return get_client_val()
+        if name.startswith('__'):
+            raise AttributeError('Pin object has no attribute %r' % name)
+        return self.__getitem__(name)
 
     def __getitem__(self, name):
-        return self.__getattr__(name)
+        check_name(name)
+        return get_pin_value(name, self._strict)
 
     def __setattr__(self, name, value):
         """
         __setattr__ will be invoked regardless of whether the attribute be found
         """
+        assert name != 'use_strict', "'use_strict' is a reserve name, can't use as pin widget name"
         check_name(name)
-        send_msg('pin_update', spec=dict(name=name, attributes={"value": value}))
+        self.__setitem__(name, value)
 
     def __setitem__(self, name, value):
-        self.__setattr__(name, value)
+        send_msg('pin_update', spec=dict(name=name, attributes={"value": value}))
 
 
 # pin widgets value getter (and setter).
@@ -309,3 +332,32 @@ def pin_update(name, **spec):
     check_name(name)
     attributes = parse_input_update_spec(spec)
     send_msg('pin_update', spec=dict(name=name, attributes=attributes))
+
+
+def pin_on_change(name, onchange=None, clear=False, init_run=False, **callback_options):
+    """
+    Bind a callback function to pin widget, the function will be called when user change the value of the pin widget.
+
+    The ``onchange`` callback is invoked with one argument, the changed value of the pin widget.
+    You can bind multiple functions to one pin widget, those functions will be invoked sequentially
+    (default behavior, can be changed by `clear` parameter).
+
+    :param str name: pin widget name
+    :param callable onchange: callback function
+    :param bool clear: whether to clear the previous callbacks bound to this pin widget.
+       If you just want to clear callbacks and not set new callback, use ``pin_on_change(name, clear=True)``.
+    :param bool init_run: whether to run the ``onchange`` callback once immediately before the pin widget changed.
+       This parameter can be used to initialize the output.
+    :param callback_options: Other options of the ``onclick`` callback.
+       Refer to the ``callback_options`` parameter of :func:`put_buttons() <pywebio.output.put_buttons>`
+
+    .. versionadded:: 1.6
+    """
+    assert not (onchange is None and clear is False), "When `onchange` is `None`, `clear` must be `True`"
+    if onchange is not None:
+        callback_id = output_register_callback(onchange, **callback_options)
+        if init_run:
+            onchange(pin[name])
+    else:
+        callback_id = None
+    send_msg('pin_onchange', spec=dict(name=name, callback_id=callback_id, clear=clear))
